package org.eclipse.paho.client.mqttv3;

import com.skt.prod.comm.lib.utils.LogEx;
import com.skt.prod.phone.lib.business.AbstractReleaseManager;

import java.io.IOException;
import java.net.InetAddress;
import java.net.Socket;
import java.security.KeyManagementException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;

/**
 * 기존 ProdSSLSocketFactory
 * Created by hongkeun on 2017-02-22.
 */
public class ProdGroupCallSSLSocketFactory extends SSLSocketFactory {
    private static boolean DEBUG = AbstractReleaseManager.DEBUG;
    private static final String TAG = "ProdGroupCallSSLSocketFactory";

    private static final Object sHttpsTrustCertsLock = new Object();
    private static TrustManager[] sHttpsTrustCerts = null;
    private final SSLSocketFactory mFactory;

    public ProdGroupCallSSLSocketFactory() throws KeyManagementException, NoSuchAlgorithmException, KeyStoreException {
        if (DEBUG) {
            LogEx.v(TAG, "AirSSLSocketFactory()");
        }

        synchronized (sHttpsTrustCertsLock) {
            if (sHttpsTrustCerts == null) {
                TrustManagerFactory factory = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
                factory.init((KeyStore) null);
                TrustManager[] trustManagers = factory.getTrustManagers();
                if (trustManagers.length == 0) {
                    throw new NoSuchAlgorithmException("no trust manager found");
                } else {
                    sHttpsTrustCerts = new TrustManager[]{trustManagers[0]};
                }
            }
        }

        SSLContext sslcontext = SSLContext.getInstance("TLS");
        sslcontext.init(null, sHttpsTrustCerts, null);
        mFactory = sslcontext.getSocketFactory();
    }

    @Override
    public String[] getDefaultCipherSuites() {
        return new String[0];
    }

    @Override
    public String[] getSupportedCipherSuites() {
        return new String[0];
    }

    @Override
    public Socket createSocket(Socket s, String host, int port, boolean autoClose) throws IOException {
        return mFactory.createSocket(s, host, port, autoClose);
    }

    public Socket createSocket() throws IOException {
        return mFactory.createSocket();
    }

    @Override
    public Socket createSocket(String host, int port) throws IOException {
        return mFactory.createSocket(host, port);
    }

    @Override
    public Socket createSocket(String host, int port, InetAddress localHost, int localPort) throws IOException {
        return mFactory.createSocket(host, port, localHost, localPort);
    }

    @Override
    public Socket createSocket(InetAddress host, int port) throws IOException {
        return mFactory.createSocket(host, port);
    }

    @Override
    public Socket createSocket(InetAddress address, int port, InetAddress localAddress, int localPort) throws IOException {
        return mFactory.createSocket(address, port, localAddress, localPort);
    }

    public boolean equals(Object obj) {
        return obj != null && obj.getClass().equals(ProdGroupCallSSLSocketFactory.class);
    }

    public int hashCode() {
        return ProdGroupCallSSLSocketFactory.class.hashCode();
    }
}

