/*******************************************************************************
 * Copyright (c) 2014 IBM Corp.
 * <p>
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 * <p>
 * The Eclipse Public License is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */

package org.eclipse.paho.client.mqttv3;

import com.skt.prod.comm.lib.utils.LogEx;
import com.skt.prod.phone.lib.business.AbstractReleaseManager;

import org.eclipse.paho.client.mqttv3.internal.ClientComms;
import org.eclipse.paho.client.mqttv3.internal.ClientState;

import java.text.MessageFormat;
import java.util.Timer;
import java.util.TimerTask;

/**
 * Default ping sender implementation
 * <p/>
 * <p>This class implements the {@link MqttPingSender} pinger interface
 * allowing applications to send ping packet to server every keep alive interval.
 * </p>
 *
 * @see MqttPingSender
 */
public class TimerPingSender implements MqttPingSender {
    private static final boolean DEBUG = AbstractReleaseManager.DEBUG;
    private static String LOG_TAG = "TimerPingSender";

    /**
     * keepalive 주기와 checkForActivity 메소드를 위해 챙김.
     */
    private ClientComms mClientComms;
    private Timer mTimer;

    public void init(ClientComms comms) {
        if (comms == null) {
            throw new IllegalArgumentException("ClientComms cannot be null.");
        }
        this.mClientComms = comms;
    }

    public void start() {
        String clientid = mClientComms.getAsyncClient().getClientId();

        if (DEBUG) {
            LogEx.v(LOG_TAG, "[start] " + MessageFormat.format("start timer for client:{0}",
                    new Object[]{clientid}));
        }

        mTimer = new Timer("MQTT Ping: " + clientid);
        //Check ping after first keep alive interval.
        mTimer.schedule(new PingTask(), ClientState.PING_TIMEOUT_IN_MILLS);
    }

    public void stop() {
        if (DEBUG) {
            LogEx.v(LOG_TAG, "[stop] " + "stop");
        }
        if (mTimer != null) {
            mTimer.cancel();
        }
    }

    public void schedule(long delayInMilliseconds) {
        mTimer.schedule(new PingTask(), delayInMilliseconds);
    }

    class PingTask extends TimerTask {
        public void run() {
            if (DEBUG) {
                LogEx.v(LOG_TAG, "[PingTask.run] " + MessageFormat.format("Check schedule at {0}", new Object[]{Long.valueOf(System.currentTimeMillis())}));
            }
            mClientComms.checkForActivity();
        }
    }
}
